@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '1.071';
+$BZ::Client::Bug::VERSION = '1.072';
 use BZ::Client::API();
 
 our @ISA = qw(BZ::Client::API);
@@ -17,7 +17,7 @@ sub legal_values {
     my $params = { 'field' => $field };
     my $result = $class->api_call($client, 'Bug.legal_values', $params);
     my $values = $result->{'values'};
-    if (!$values  ||  'ARRAY' ne ref($values)) {
+    if (!$values || 'ARRAY' ne ref($values)) {
         $class->error($client, 'Invalid reply by server, expected array of values.');
     }
     $client->log('debug', 'BZ::Client::Bug::legal_values: Got ' . join(',', @$values));
@@ -225,7 +225,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 1.071
+version 1.072
 
 =head1 SYNOPSIS
 
@@ -241,10 +241,58 @@ This class provides methods for accessing and managing bugs in Bugzilla.
 
 This section lists the class methods, which are available in this module.
 
+=head2 fields
+
+=head2 legal_values
+
+  my $values = BZ::Client::Bug->legal_values( $client, $field )
+
+Tells you what values are allowed for a particular field.
+
+Note: This is deprecated in Bugzilla, use L<fields> instead.
+
+Params:
+
+=over 4
+
+=item $field
+
+The name of the field you want information about. This should be the same as the name you would use in L<create>, below.
+
+=back
+
+Returns:
+
+=over 4
+
+=item $values
+
+An arrayref of strings: the legal values for this field. The values will be sorted as they normally would be in Bugzilla.
+
+=back
+
+Errors:
+
+=over 4
+
+=item 106 - Invalid Product
+
+You were required to specify a product, and either you didn't, or you specified an invalid product (or a product that you can't access).
+
+=item 108 - Invalid Field Name
+
+You specified a field that doesn't exist or isn't a drop-down field.
+
+=back
+
 =head2 get
 
+  $ids = 101; or $ids = [ 69, 101 ]; or $ids = '69,101';
+
   my $bugs = BZ::Client::Bug->get( $client, $ids );
 
+I<$ids> is an arrayref of ids, or a scalar containing comma delimiteed ids
+
 Returns a list of bug instances with the given ID's.
 
 =head2 new
