@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '1.071';
+$BZ::Client::Bugzilla::VERSION = '1.072';
 use BZ::Client::API();
 
 our @ISA = qw(BZ::Client::API);
@@ -54,7 +54,7 @@ BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla:
 
 =head1 VERSION
 
-version 1.071
+version 1.072
 
 =head1 SYNOPSIS
 
@@ -85,6 +85,8 @@ Returns a hash ref with information about the Bugzilla servers extensions.
 
 Returns a hash ref with information about the Bugzilla servers local time.
 
+Note: as of Bugzilla 3.6 this will always return UTC values.
+
 =head2 timezone
 
   my $timezone = BZ::Client::Bugzilla->timezone( $client );
@@ -92,12 +94,25 @@ Returns a hash ref with information about the Bugzilla servers local time.
 Returns the Bugzilla servers timezone as a numeric value. This method
 is deprecated: Use L</time> instead.
 
+Note: as of Bugzilla 3.6 the timezone is always +0000 (UTC)
+Also, Bugzilla has depreceated but not yet removed this API call
+
 =head2 version
 
   my $version = BZ::Client::Bugzilla->version( $client );
 
 Returns the Bugzilla servers version.
 
+=head1 TODO
+
+=over 4
+
+=item paramaters (added in 4.4)
+
+=item last_audit_time (added in 4.4)
+
+=back
+
 =head1 SEE ALSO
 
   L<BZ::Client>, L<BZ::Client::API>
